import numpy as np
import matplotlib.pyplot as plt
from scipy.fftpack import *

plt.rcParams.update({'font.size': 20}) 

### Paramètres d'acquisition
t_max = 1
N = 100
N_theo = 8 * N
dt = t_max / N
T_e = 0.1
N_ech = int(N * dt / T_e)

### Signal temporel triangle
t_theo = np.linspace(-t_max, t_max, N+1, endpoint=True)
triangle_theo = np.zeros_like(t_theo)
for it, t in enumerate(t_theo):
    triangle = 8 * t + 4
    if t > 0: triangle = -8 * t + 4
    if triangle < 0: triangle = 0
    triangle_theo[it] = triangle

### Paramètres du plot
fig, ax = plt.subplots(2, 2, figsize=(10, 6))
ax[0, 0].plot(t_theo, triangle_theo)
ax[0, 0].grid()
ax[0, 0].set_xlabel('$t$ [s]')
ax[0, 0].set_ylabel('s(t)')
ax[0, 0].set_xlim(-t_max, t_max)

# yf = fft(peigne)
# xf = np.linspace(0.0, 1.0 / (2.0 * T_e), N_ech // 2)
y_fft_theo = fft(triangle_theo, N_theo)
x_fft_theo = np.linspace(0.0, 1.0 / (2.0 * dt), N_theo // 2)
ax[0, 1].plot(x_fft_theo, 2.0 / (4*N_ech) * np.abs(y_fft_theo[0:N_theo // 2]),label='$F_{max} \sim 10 $Hz' )
# ax[1].plot(xf, 2.0 / N_ech * np.abs(yf[0:N_ech // 2]))
ax[0, 1].grid()
ax[0, 1].set_xlabel('$f$ [Hz]')
ax[0, 1].set_ylabel(r'$s(f)$ (normalisé)')
ax[0, 1].set_xlim(0, 50)
ax[0, 1].legend()

t = t_theo[::N // N_ech]
triangle_ech = triangle_theo[::N // N_ech]
triangle = np.zeros_like(triangle_theo)
for i in np.arange(0, N, N // N_ech):
    triangle[i] = triangle_theo[i]

ax[1, 0].plot(t_theo, triangle_theo, '--')
ax[1, 0].stem(t, triangle_ech, basefmt='none', markerfmt='go', linefmt='g',label='$F_{ech}$=10 Hz')
ax[1, 0].grid()
ax[1, 0].set_xlabel('$t$ [s]')
ax[1, 0].set_ylabel('$s_{\mathrm{ech}}(t)$')
ax[1, 0].set_xlim(-t_max, t_max)
ax[1, 0].legend()

#yf = fft(triangle, N)
xf = np.linspace(0.0, 1.0 / (2.0 * dt), N // 2 +1, endpoint=True)
y_fft_theo = fft(triangle, N_theo)
x_fft_theo = np.linspace(0.0, 1.0 / (2.0 * dt), N_theo // 2)
ax[1, 1].plot(x_fft_theo, 2.0 / (2*N_ech) * np.abs(y_fft_theo[0:N_theo // 2]))
#ax[1, 1].stem(xf, 2.0 / N_ech * np.abs(yf[0:N // 2+1]), basefmt='none', markerfmt='go', linefmt='g')
ax[1, 1].grid()
ax[1, 1].set_xlabel('$f$ [Hz]')
ax[1, 1].set_ylabel(r'$s_{éch}(f)$ (normalisé)')
ax[1, 1].set_xlim(0, 50)

fig.tight_layout()
fig.savefig('triangle_fft.pdf', dpi=100)

plt.show()
